Skip to contents

This function downloads data from AUTOTYP (https://github.com/autotyp/autotyp-data#the-autotyp-database) and changes language names to the names from lingtypology database. You need the internet connection.

Usage

autotyp.feature(features, version = "v1.1.1", na.rm = TRUE)

Arguments

features

A character vector that define with a feature names from AUTOTYP.

version

A character verctor that defines version of the dataset.

na.rm

Logical. If TRUE function removes all languages not available in lingtypology database. By default is TRUE.

Examples

# autotyp.feature(c('Has Gender', 'Has Numeral Classifiers'))