Skip to contents

This function downloads data from Grambank (https://grambank.clld.org/) and changes language names to the names from lingtypology database. You need the internet connection.

Usage

grambank.feature(features, version = "v1.0.3", na.rm = TRUE)

Arguments

features

A character vector that defines feature ids from Grambank (e. g. "gb026", "gb042").

version

A character verctor that defines version of the dataset

na.rm

Logical. If TRUE function removes all languages not available in lingtypology database. By default is TRUE.

Author

George Moroz <agricolamz@gmail.com>

Examples

# grambank.feature(c("gb026", "gb042"))