Skip to contents

This function downloads data from UraLex (https://github.com/lexibank/uralex/) and changes language names to the names from lingtypology database. You need the internet connection.

Usage

uralex.feature(version = "v2.0", na.rm = TRUE)

Arguments

version

A character verctor that defines version of the dataset

na.rm

Logical. If TRUE function removes all languages not available in lingtypology database. By default is TRUE.

Author

George Moroz <agricolamz@gmail.com>

Examples

# uralex.feature()